@@ -6,7 +6,6 @@ import time
 
 import ruamel.yaml
 
-from .vendored import travis_encrypt as travis
 from . import github
 
 
@@ -20,20 +19,60 @@ try:
     with open(os.path.expanduser('~/.conda-smithy/circle.token'), 'r') as fh:
         circle_token = fh.read().strip()
 except IOError:
-    print('No circle token. Put one in ~/.conda-smithy/circle.token')
+    print('No circle token.  Create a token at https://circleci.com/account/api and\n'
+          'put it in ~/.conda-smithy/circle.token')
 
 try:
     with open(os.path.expanduser('~/.conda-smithy/appveyor.token'), 'r') as fh:
         appveyor_token = fh.read().strip()
 except IOError:
-    print('No appveyor token. Put one in ~/.conda-smithy/appveyor.token')
+    print('No appveyor token. Create a token at https://ci.appveyor.com/api-token and\n'
+          'Put one in ~/.conda-smithy/appveyor.token')
+
+try:
+    anaconda_token = os.environ['BINSTAR_TOKEN']
+except KeyError:
+    try:
+        with open(os.path.expanduser('~/.conda-smithy/anaconda.token'), 'r') as fh:
+            anaconda_token = fh.read().strip()
+    except IOError:
+        print('No anaconda token. Create a token via\n'
+              '  anaconda auth --create --name conda-smithy --scopes "repos conda api"\n'
+              'and put it in ~/.conda-smithy/anaconda.token')
+
+
+def travis_headers():
+    headers = {
+               # If the user-agent isn't defined correctly, we will recieve a 403.
+               'User-Agent': 'Travis/1.0',
+               'Accept': 'application/vnd.travis-ci.2+json',
+               'Content-Type': 'application/json'
+               }
+    endpoint = 'https://api.travis-ci.org'
+    url = '{}/auth/github'.format(endpoint)
+    data = {"github_token": github.gh_token()}
+    travis_token = os.path.expanduser('~/.conda-smithy/travis.token')
+    if not os.path.exists(travis_token):
+        response = requests.post(url, json=data, headers=headers)
+        if response.status_code != 201:
+            response.raise_for_status()
+        token = response.json()['access_token']
+        with open(travis_token, 'w') as fh:
+            fh.write(token)
+        # TODO: Set the permissions on the file.
+    else:
+        with open(travis_token, 'r') as fh:
+            token = fh.read().strip()
+
+    headers['Authorization'] = 'token {}'.format(token)
+    return headers
 
 
 def add_token_to_circle(user, project):
     url_template = ('https://circleci.com/api/v1/project/{user}/{project}/envvar?'
                     'circle-token={token}')
     url = url_template.format(token=circle_token, user=user, project=project)
-    data = {'name': 'BINSTAR_TOKEN', 'value': os.environ['BINSTAR_TOKEN']}
+    data = {'name': 'BINSTAR_TOKEN', 'value': anaconda_token}
     response = requests.post(url, data)
     if response.status_code != 201:
         raise ValueError(response)
@@ -53,7 +92,7 @@ def add_project_to_circle(user, project):
     # It is a strange response code, but is doing what was asked...
     if response.status_code != 400:
         response.raise_for_status()
-    print(' * {}/{} enabled on CircleCI')
+    print(' * {}/{} enabled on CircleCI'.format(user, project))
 
 
 def add_project_to_appveyor(user, project):
@@ -79,7 +118,7 @@ def add_project_to_appveyor(user, project):
 def appveyor_encrypt_binstar_token(feedstock_directory, user, project):
     headers = {'Authorization': 'Bearer {}'.format(appveyor_token)}
     url = 'https://ci.appveyor.com/api/account/encrypt'
-    response = requests.post(url, headers=headers, data={"plainValue": os.environ['BINSTAR_TOKEN']})
+    response = requests.post(url, headers=headers, data={"plainValue": anaconda_token})
     if response.status_code != 200:
         raise ValueError(response)
 
@@ -111,8 +150,9 @@ def appveyor_configure(user, project):
     content = response.json()
     settings = content['settings']
     skip_appveyor = u'skipBranchesWithoutAppveyorYml'
-    print('{: <30}: Current setting for {} = {}.'
-          ''.format(project, skip_appveyor, settings[skip_appveyor]))
+    if not settings[skip_appveyor]:
+        print('{: <30}: Current setting for {} = {}.'
+              ''.format(project, skip_appveyor, settings[skip_appveyor]))
     settings[skip_appveyor] = True
     url = 'https://ci.appveyor.com/api/projects'.format(user, project)
 
@@ -122,21 +162,9 @@ def appveyor_configure(user, project):
 
 
 def add_project_to_travis(user, project):
-    headers = {
-               # If the user-agent isn't defined correctly, we will recieve a 403.
-               'User-Agent': 'MyClient/1.0.0',
-               'Accept': 'application/vnd.travis-ci.2+json',
-               }
+    headers = travis_headers()
     endpoint = 'https://api.travis-ci.org'
-    url = '{}/auth/github'.format(endpoint)
-    data = {"github_token": github.gh_token()}
-    response = requests.post(url, json=data, headers=headers)
-    if response.status_code != 201:
-        response.raise_for_status()
-
-    token = response.json()['access_token']
-    headers['Authorization'] = 'token {}'.format(token)
-
+    
     url = '{}/hooks'.format(endpoint)
 
     found = False
@@ -180,7 +208,7 @@ def add_project_to_travis(user, project):
 
 
 def travis_token_update_conda_forge_config(feedstock_directory, user, project):
-    item = 'BINSTAR_TOKEN="{}"'.format(os.environ['BINSTAR_TOKEN'])
+    item = 'BINSTAR_TOKEN="{}"'.format(anaconda_token)
     slug = "{}/{}".format(user, project)
 
     forge_yaml = os.path.join(feedstock_directory, 'conda-forge.yml')
@@ -195,14 +223,75 @@ def travis_token_update_conda_forge_config(feedstock_directory, user, project):
         code = {}
 
     code.setdefault('travis', {}).setdefault('secure', {})['BINSTAR_TOKEN'] = (
-        _encrypt_binstar_token(slug, item)
+        travis_encrypt_binstar_token(slug, item)
     )
     with open(forge_yaml, 'w') as fh:
         fh.write(ruamel.yaml.dump(code, Dumper=ruamel.yaml.RoundTripDumper))
 
 
-def _encrypt_binstar_token(slug, item):
-    return travis.encrypt(slug, item.encode()).decode('utf-8')
+def travis_encrypt_binstar_token(repo, string_to_encrypt):
+    # Copyright 2014 Matt Martz <matt@sivel.net>
+    # All Rights Reserved.
+    #
+    #    Licensed under the Apache License, Version 2.0 (the "License"); you may
+    #    not use this file except in compliance with the License. You may obtain
+    #    a copy of the License at
+    #
+    #         http://www.apache.org/licenses/LICENSE-2.0
+    #
+    #    Unless required by applicable law or agreed to in writing, software
+    #    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
+    #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
+    #    License for the specific language governing permissions and limitations
+    #    under the License.
+    from Crypto.PublicKey import RSA
+    from Crypto.Cipher import PKCS1_v1_5
+    import base64
+
+    keyurl = 'https://api.travis-ci.org/repos/{0}/key'.format(repo)
+    r = requests.get(keyurl, headers=travis_headers())
+    r.raise_for_status()
+    public_key = r.json()['key']
+    key = RSA.importKey(public_key)
+    cipher = PKCS1_v1_5.new(key)
+    return base64.b64encode(cipher.encrypt(string_to_encrypt.encode())).decode('utf-8')
+
+
+def travis_configure(user, project):
+    """Configure travis so that it skips building if there is no .travis.yml present."""
+    endpoint = 'https://api.travis-ci.org'
+    headers = travis_headers()
+
+    url = '{}/hooks'.format(endpoint)
+
+    response = requests.get(url, headers=headers)
+    content = response.json()
+    try:
+        found = [hooked for hooked in content['hooks']
+                 if hooked['owner_name'] == user and hooked['name'] == project]
+    except KeyError:
+        print("Unable to find {user}/{project}".format(user=user, project=project))
+        raise
+
+    if found[0]['active'] is False:
+        raise InputError(
+            "Repo {user}/{project} is not active on Travis CI".format(user=user, project=project)
+        )
+
+    url = '{}/repos/{user}/{project}'.format(endpoint, user=user, project=project)
+    response = requests.get(url, headers=headers)
+    content = response.json()
+    repo_id = content['repo']['id']
+
+    url = '{}/repos/{repo_id}/settings'.format(endpoint, repo_id=repo_id)
+    data = {
+        "settings": {
+            "builds_only_with_travis_yml": True,
+        }
+    }
+    response = requests.patch(url, json=data, headers=headers)
+    if response.status_code != 204:
+        response.raise_for_status()
 
 
 def add_conda_linting(user, repo):
